@@ -1,6 +1,7 @@
 from __future__ import print_function, division, absolute_import
 
 import atexit
+from functools import partial
 import logging
 import os
 import shutil
@@ -10,6 +11,7 @@ import tempfile
 import click
 
 from distributed import Scheduler
+from distributed.security import Security
 from distributed.utils import ignoring, open_port, get_ip_interface
 from distributed.http import HTTPScheduler
 from distributed.cli.utils import (check_python_3, install_signal_handlers,
@@ -20,28 +22,36 @@ from tornado.ioloop import IOLoop
 logger = logging.getLogger('distributed.scheduler')
 
 
+pem_file_option_type = click.Path(exists=True, resolve_path=True)
+
 @click.command()
+@click.option('--host', type=str, default='',
+              help="URI, IP or hostname of this server")
 @click.option('--port', type=int, default=None, help="Serving port")
+@click.option('--interface', type=str, default=None,
+              help="Preferred network interface like 'eth0' or 'ib0'")
+@click.option('--tls-ca-file', type=pem_file_option_type, default=None,
+              help="CA cert(s) file for TLS (in PEM format)")
+@click.option('--tls-cert', type=pem_file_option_type, default=None,
+              help="certificate file for TLS (in PEM format)")
+@click.option('--tls-key', type=pem_file_option_type, default=None,
+              help="private key file for TLS (in PEM format)")
 # XXX default port (or URI) values should be centralized somewhere
 @click.option('--http-port', type=int, default=9786,
               help="HTTP port for JSON API diagnostics")
 @click.option('--bokeh-port', type=int, default=8787,
               help="Bokeh port for visual diagnostics")
-@click.option('--bokeh-external-port', type=int, default=None,
-              help="Optional port for the external (old) Bokeh server")
 @click.option('--bokeh-internal-port', type=int, default=None,
               help="Deprecated. Use --bokeh-port instead")
 @click.option('--bokeh/--no-bokeh', '_bokeh', default=True, show_default=True,
               required=False, help="Launch Bokeh Web UI")
-@click.option('--host', type=str, default='',
-              help="IP, hostname or URI of this server")
-@click.option('--interface', type=str, default=None,
-              help="Preferred network interface like 'eth0' or 'ib0'")
 @click.option('--show/--no-show', default=False, help="Show web UI")
 @click.option('--bokeh-whitelist', default=None, multiple=True,
               help="IP addresses to whitelist for bokeh.")
-@click.option('--prefix', type=str, default=None,
+@click.option('--bokeh-prefix', type=str, default=None,
               help="Prefix for the bokeh app")
+@click.option('--prefix', type=str, default=None,
+              help="Deprecated, see --bokeh-prefix")
 @click.option('--use-xheaders', type=bool, default=False, show_default=True,
               help="User xheaders in bokeh app for ssl termination in header")
 @click.option('--pid-file', type=str, default='',
@@ -54,10 +64,10 @@ logger = logging.getLogger('distributed.scheduler')
               help="Directory to place scheduler files")
 @click.option('--preload', type=str, multiple=True,
               help='Module that should be loaded by each worker process like "foo.bar" or "/path/to/foo.py"')
-def main(host, port, http_port, bokeh_port, bokeh_external_port,
-         bokeh_internal_port, show, _bokeh, bokeh_whitelist, prefix,
-         use_xheaders, pid_file, scheduler_file, interface, local_directory,
-         preload):
+def main(host, port, http_port, bokeh_port, bokeh_internal_port, show, _bokeh,
+         bokeh_whitelist, bokeh_prefix, use_xheaders, pid_file, scheduler_file,
+         interface, local_directory, preload, prefix, tls_ca_file, tls_cert,
+         tls_key):
 
     if bokeh_internal_port:
         print("The --bokeh-internal-port keyword has been removed.\n"
@@ -65,6 +75,15 @@ def main(host, port, http_port, bokeh_port, bokeh_external_port,
               "Use --bokeh-port %d instead" % bokeh_internal_port)
         sys.exit(1)
 
+    if prefix:
+        print("The --prefix keyword has moved to --bokeh-prefix")
+        sys.exit(1)
+
+    sec = Security(tls_ca_file=tls_ca_file,
+                   tls_scheduler_cert=tls_cert,
+                   tls_scheduler_key=tls_key,
+                   )
+
     if pid_file:
         with open(pid_file, 'w') as f:
             f.write(str(os.getpid()))
@@ -106,28 +125,14 @@ def main(host, port, http_port, bokeh_port, bokeh_external_port,
     if _bokeh:
         with ignoring(ImportError):
             from distributed.bokeh.scheduler import BokehScheduler
-            services[('bokeh', bokeh_port)] = BokehScheduler
+            services[('bokeh', bokeh_port)] = partial(BokehScheduler,
+                                                      prefix=bokeh_prefix)
     scheduler = Scheduler(loop=loop, services=services,
-                          scheduler_file=scheduler_file)
+                          scheduler_file=scheduler_file,
+                          security=sec)
     scheduler.start(addr)
     preload_modules(preload, parameter=scheduler, file_dir=local_directory)
 
-    bokeh_proc = None
-    if _bokeh and bokeh_external_port is not None:
-        if bokeh_external_port == 0: # This is a hack and not robust
-            bokeh_port = open_port() # This port may be taken by the OS
-        try:                         # before we successfully pass it to Bokeh
-            from distributed.bokeh.application import BokehWebInterface
-            bokeh_proc = BokehWebInterface(http_port=http_port,
-                    scheduler_address=scheduler.address,
-                    bokeh_port=bokeh_external_port,
-                    bokeh_whitelist=bokeh_whitelist, show=show, prefix=prefix,
-                    use_xheaders=use_xheaders, quiet=False)
-        except ImportError:
-            logger.info("Please install Bokeh to get Web UI")
-        except Exception as e:
-            logger.warn("Could not start Bokeh web UI", exc_info=True)
-
     logger.info('Local Directory: %26s', local_directory)
     logger.info('-' * 47)
     try:
@@ -135,8 +140,6 @@ def main(host, port, http_port, bokeh_port, bokeh_external_port,
         loop.close()
     finally:
         scheduler.stop()
-        if bokeh_proc:
-            bokeh_proc.close()
         if local_directory_created:
             shutil.rmtree(local_directory)
 
