@@ -7,9 +7,7 @@ import logging
 from six import with_metaclass
 
 from tornado import gen
-from tornado.ioloop import IOLoop
 
-from ..config import config
 from ..metrics import time
 from . import registry
 from .addressing import parse_address
@@ -80,6 +78,15 @@ class Comm(with_metaclass(ABCMeta)):
         The peer's address.  For logging and debugging purposes only.
         """
 
+    @property
+    def extra_info(self):
+        """
+        Return backend-specific information about the communication,
+        as a dict.  Typically, this is information which is initialized
+        when the communication is established and doesn't vary afterwards.
+        """
+        return {}
+
 
 class Listener(with_metaclass(ABCMeta)):
 
@@ -131,7 +138,7 @@ class Connector(with_metaclass(ABCMeta)):
 
 
 @gen.coroutine
-def connect(addr, timeout=3, deserialize=True):
+def connect(addr, timeout=3, deserialize=True, connection_args=None):
     """
     Connect to the given address (a URI such as ``tcp://127.0.0.1:1234``)
     and yield a ``Comm`` object.  If the connection attempt fails, it is
@@ -153,7 +160,8 @@ def connect(addr, timeout=3, deserialize=True):
 
     while True:
         try:
-            future = connector.connect(loc, deserialize=deserialize)
+            future = connector.connect(loc, deserialize=deserialize,
+                                       **(connection_args or {}))
             comm = yield gen.with_timeout(timedelta(seconds=deadline - time()),
                                           future,
                                           quiet_exceptions=EnvironmentError)
@@ -172,7 +180,7 @@ def connect(addr, timeout=3, deserialize=True):
     raise gen.Return(comm)
 
 
-def listen(addr, handle_comm, deserialize=True):
+def listen(addr, handle_comm, deserialize=True, connection_args=None):
     """
     Create a listener object with the given parameters.  When its ``start()``
     method is called, the listener will listen on the given address
@@ -184,4 +192,5 @@ def listen(addr, handle_comm, deserialize=True):
     scheme, loc = parse_address(addr)
     backend = registry.get_backend(scheme)
 
-    return backend.get_listener(loc, handle_comm, deserialize)
+    return backend.get_listener(loc, handle_comm, deserialize,
+                                **(connection_args or {}))
