@@ -98,23 +98,23 @@ class Server(object):
         self.listener = None
         self.io_loop = io_loop or IOLoop.current()
 
-        if hasattr(self, 'loop'):
-            # XXX?
-            with ignoring(ImportError):
-                from .counter import Digest
-                self.digests = defaultdict(partial(Digest, loop=self.loop))
+        # Statistics counters for various events
+        with ignoring(ImportError):
+            from .counter import Digest
+            self.digests = defaultdict(partial(Digest, loop=self.io_loop))
 
-            from .counter import Counter
-            self.counters = defaultdict(partial(Counter, loop=self.loop))
-            self.events = defaultdict(lambda: deque(maxlen=10000))
-            self.event_counts = defaultdict(lambda: 0)
+        from .counter import Counter
+        self.counters = defaultdict(partial(Counter, loop=self.io_loop))
+        self.events = defaultdict(lambda: deque(maxlen=10000))
+        self.event_counts = defaultdict(lambda: 0)
 
-            pc = PeriodicCallback(self.monitor.update, 500, io_loop=self.loop)
-            self.loop.add_callback(pc.start)
-            if self.digests is not None:
-                self._last_tick = time()
-                self._tick_pc = PeriodicCallback(self._measure_tick, 20, io_loop=self.loop)
-                self.loop.add_callback(self._tick_pc.start)
+        pc = PeriodicCallback(self.monitor.update, 500, io_loop=self.io_loop)
+        self.io_loop.add_callback(pc.start)
+        if self.digests is not None:
+            self._last_tick = time()
+            self._tick_pc = PeriodicCallback(self._measure_tick, 20,
+                                             io_loop=self.io_loop)
+            self.io_loop.add_callback(self._tick_pc.start)
 
         self.__stopped = False
 
@@ -128,6 +128,7 @@ class Server(object):
                 # raising EBADF.
                 # The demonstrator for this is Worker.terminate(), which
                 # closes the server socket in response to an incoming message.
+                # See https://github.com/tornadoweb/tornado/issues/2069
                 self.io_loop.add_callback(self.listener.stop)
 
     def _measure_tick(self):
