@@ -1,9 +1,11 @@
 from __future__ import print_function, division, absolute_import
 
+import sys
 from zlib import crc32
 
 import numpy as np
 import pytest
+import six
 
 from distributed.protocol import (serialize, deserialize, decompress, dumps,
         loads, to_serialize, msgpack)
@@ -29,6 +31,9 @@ def test_serialize():
 @pytest.mark.parametrize('x',
         [np.ones(5),
          np.array(5),
+         np.random.random((5, 5)),
+         np.random.random((5, 5))[::2, :],
+         np.random.random((5, 5))[:, ::2],
          np.asfortranarray(np.random.random((5, 5))),
          np.asfortranarray(np.random.random((5, 5)))[::2, :],
          np.asfortranarray(np.random.random((5, 5)))[:, ::2],
@@ -48,6 +53,10 @@ def test_serialize():
          np.array(['abc'], dtype=object),
          np.ones(shape=(5,), dtype=('f8', 32)),
          np.ones(shape=(5,), dtype=[('x', 'f8', 32)]),
+         np.ones(shape=(5,), dtype=np.dtype([('a', 'i1'), ('b', 'f8')], align=False)),
+         np.ones(shape=(5,), dtype=np.dtype([('a', 'i1'), ('b', 'f8')], align=True)),
+         np.ones(shape=(5,), dtype=np.dtype([('a', 'm8[us]')], align=False)),
+         np.ones(shape=(5,), dtype=np.dtype([('a', 'm8')], align=False)),  # this dtype fails unpickling
          np.array([(1, 'abc')], dtype=[('x', 'i4'), ('s', object)]),
          np.zeros(5000, dtype=[('x%d'%i,'<f8') for i in range(4)]),
          np.zeros(5000, dtype='S32'),
@@ -61,10 +70,25 @@ def test_dumps_serialize_numpy(x):
     y = deserialize(header, frames)
 
     np.testing.assert_equal(x, y)
-    if np.isfortran(x):
+    if x.flags.c_contiguous or x.flags.f_contiguous:
         assert x.strides == y.strides
 
 
+def test_dumps_serialize_numpy_custom_dtype():
+    from six.moves import builtins
+    test_rational = pytest.importorskip('numpy.core.test_rational')
+    rational = test_rational.rational
+    try:
+        builtins.rational = rational  # Work around https://github.com/numpy/numpy/issues/9160
+        x = np.array([1], dtype=rational)
+        header, frames = serialize(x)
+        y = deserialize(header, frames)
+
+        np.testing.assert_equal(x, y)
+    finally:
+        del builtins.rational
+
+
 def test_memmap():
     with tmpfile('npy') as fn:
         with open(fn, 'wb') as f:  # touch file
@@ -162,4 +186,19 @@ def test_dont_compress_uncompressable_data():
 @gen_cluster(client=True, timeout=60)
 def test_dumps_large_blosc(c, s, a, b):
     x = c.submit(np.ones, BIG_BYTES_SHARD_SIZE * 2, dtype='u1')
-    result = yield x._result()
+    result = yield x
+
+
+def test_compression_takes_advantage_of_itemsize():
+    blosc = pytest.importorskip('blosc')
+    x = np.arange(1000000, dtype='i8')
+
+    assert (len(blosc.compress(x.data, typesize=8))
+          < len(blosc.compress(x.data, typesize=1)))
+
+    _, a = serialize(x)
+    aa = [maybe_compress(frame)[1] for frame in a]
+    _, b = serialize(x.view('u1'))
+    bb = [maybe_compress(frame)[1] for frame in b]
+
+    assert sum(map(len, aa)) < sum(map(len, bb))
