@@ -1031,21 +1031,26 @@ def test_close_worker(c, s, a, b):
 @gen_cluster(client=True, Worker=Nanny, timeout=20)
 def test_close_nanny(c, s, a, b):
     assert len(s.workers) == 2
-    old_process = a.process
 
-    assert old_process.is_alive()
-    yield s.close_worker(worker=a.worker_address)
+    assert a.process.is_alive()
+    a_worker_address = a.worker_address
+    start = time()
+    yield s.close_worker(worker=a_worker_address)
 
     assert len(s.workers) == 1
-    assert a.worker_address not in s.workers
-    assert not old_process.is_alive()
+    assert a_worker_address not in s.workers
+    assert not a.is_alive()
+    assert a.pid is None
 
     for i in range(10):
         yield gen.sleep(0.1)
         assert len(s.workers) == 1
+        assert not a.is_alive()
+        assert a.pid is None
 
-        assert not old_process.is_alive()
-        assert not a.process
+    while a.status != 'closed':
+        yield gen.sleep(0.05)
+        assert time() < start + 10
 
 
 @gen_cluster(client=True, timeout=20)
@@ -1056,21 +1061,18 @@ def test_retire_workers_close(c, s, a, b):
 
 @gen_cluster(client=True, timeout=20, Worker=Nanny)
 def test_retire_nannies_close(c, s, a, b):
-    processes = [a.process, b.process]
+    nannies = [a, b]
     yield s.retire_workers(close=True, remove=True)
     assert not s.workers
 
     start = time()
-    while True:
-        if not any(proc.is_alive() for proc in processes):
-            break
-        else:
-            yield gen.sleep(0.1)
-        assert time() < start + 5
 
-    yield gen.sleep(1)
-    assert not any(proc.is_alive() for proc in processes)
-    assert not a.process and not b.process
+    while any(n.status != 'closed' for n in nannies):
+        yield gen.sleep(0.05)
+        assert time() < start + 10
+
+    assert not any(n.is_alive() for n in nannies)
+    assert not s.workers
 
 
 @gen_cluster(client=True, ncores=[('127.0.0.1', 2)])
