@@ -18,6 +18,7 @@ from tornado import gen
 from tornado.ioloop import TimeoutError
 
 import distributed
+from distributed import Nanny
 from distributed.core import rpc, connect
 from distributed.client import _wait
 from distributed.scheduler import Scheduler
@@ -128,7 +129,7 @@ def test_worker_bad_args(c, s, a, b):
     # Make sure job died because of bad func and not because of bad
     # argument.
     with pytest.raises(ZeroDivisionError):
-        yield y._result()
+        yield y
 
     if sys.version_info[0] >= 3:
         tb = yield y._traceback()
@@ -208,7 +209,7 @@ def test_upload_file(c, s, a, b):
         return foobar.x
 
     future = c.submit(g, workers=a.address)
-    result = yield future._result()
+    result = yield future
     assert result == 123
 
     yield a._close()
@@ -241,7 +242,7 @@ def test_upload_egg(c, s, a, b):
         return testegg.inc(x)
 
     future = c.submit(g, 10, workers=a.address)
-    result = yield future._result()
+    result = yield future
     assert result == 10 + 1
 
     yield a._close()
@@ -340,7 +341,7 @@ def test_spill_to_disk(e, s):
     assert set(w.data.fast) == {y.key, z.key}
     assert set(w.data.slow) == {x.key} or set(w.data.slow) == {x.key, y.key}
 
-    yield x._result()
+    yield x
     assert set(w.data.fast) == {x.key, z.key}
     assert set(w.data.slow) == {y.key} or set(w.data.slow) == {x.key, y.key}
     yield w._close()
@@ -388,7 +389,7 @@ def test_Executor(c, s):
         yield w._start()
 
         future = c.submit(inc, 1)
-        result = yield future._result()
+        result = yield future
         assert result == 2
 
         assert e._threads  # had to do some work
@@ -435,7 +436,7 @@ def test_inter_worker_communication(c, s, a, b):
     [x, y] = yield c._scatter([1, 2], workers=a.address)
 
     future = c.submit(add, x, y, workers=b.address)
-    result = yield future._result()
+    result = yield future
     assert result == 3
 
 
@@ -444,7 +445,7 @@ def test_clean(c, s, a, b):
     x = c.submit(inc, 1, workers=a.address)
     y = c.submit(inc, x, workers=b.address)
 
-    yield y._result()
+    yield y
 
     collections = [a.tasks, a.task_state, a.startstops, a.data, a.nbytes,
                    a.durations, a.priorities, a.types, a.threads]
@@ -469,7 +470,7 @@ def test_message_breakup(c, s, a, b):
     b.target_message_size = 10 * n
     xs = [c.submit(mul, b'%d' % i, n, workers=a.address) for i in range(30)]
     y = c.submit(lambda *args: None, xs, workers=b.address)
-    yield y._result()
+    yield y
 
     assert 2 <= len(b.incoming_transfer_log) <= 20
     assert 2 <= len(a.outgoing_transfer_log) <= 20
@@ -512,7 +513,7 @@ def test_system_monitor(s, a, b):
 def test_restrictions(c, s, a, b):
     # Resource restrictions
     x = c.submit(inc, 1, resources={'A': 1})
-    yield x._result()
+    yield x
     assert a.resource_restrictions == {x.key: {'A': 1}}
     yield c._cancel(x)
 
@@ -686,7 +687,7 @@ def test_priorities(c, s, w):
     b1 = delayed(slowinc)(b, dask_key_name='b1', delay=0.05)
 
     z = delayed(add)(a2, b1)
-    future = yield c.compute(z)._result()
+    future = yield c.compute(z)
 
     log = [t for t in w.log if t[1] == 'executing' and t[2] == 'memory']
     assert [t[0] for t in log[:5]] == ['a', 'b', 'a1', 'b1', 'a2']
@@ -722,3 +723,81 @@ def test_heartbeats(c, s, a, b):
     while not all(s.worker_info[w].get('memory-rss') for w in s.workers):
         yield gen.sleep(0.01)
         assert time() < start + 2
+
+
+@pytest.mark.parametrize('worker', [Worker, Nanny])
+def test_worker_dir(worker):
+    with tmpfile() as fn:
+        @gen_cluster(client=True, worker_kwargs={'local_dir': fn})
+        def test_worker_dir(c, s, a, b):
+            directories = [info['local_directory']
+                           for info in s.worker_info.values()]
+            assert all(d.startswith(fn) for d in directories)
+            assert len(set(directories)) == 2  # distinct
+
+        test_worker_dir()
+
+
+@gen_cluster(client=True)
+def test_dataframe_attribute_error(c, s, a, b):
+    class BadSize(object):
+        def __init__(self, data):
+            self.data = data
+
+        def __sizeof__(self):
+            raise TypeError('Hello')
+
+    future = c.submit(BadSize, 123)
+    result = yield future
+    assert result.data == 123
+
+
+@gen_cluster(client=True)
+def test_fail_write_to_disk(c, s, a, b):
+    class Bad(object):
+        def __getstate__(self):
+            raise TypeError()
+
+        def __sizeof__(self):
+            return int(100e9)
+
+    future = c.submit(Bad)
+    yield _wait(future)
+
+    assert future.status == 'error'
+
+    with pytest.raises(TypeError):
+        yield future
+
+    futures = c.map(inc, range(10))
+    results = yield c._gather(futures)
+    assert results == list(map(inc, range(10)))
+
+
+@gen_cluster(client=True, worker_kwargs={'memory_limit': 1000})
+def test_fail_write_many_to_disk(c, s, a, b):
+    a.validate = False
+    b.validate = False
+    class Bad(object):
+        def __init__(self, x):
+            pass
+
+        def __getstate__(self):
+            raise TypeError()
+
+        def __sizeof__(self):
+            return 500
+
+    futures = c.map(Bad, range(10))
+    future = c.submit(lambda *args: 123, *futures)
+
+    yield _wait(future)
+
+    with pytest.raises(Exception) as info:
+        yield future
+
+    # workers still operational
+    result = yield c.submit(inc, 1, workers=a.address)
+    assert result == 2
+    result = yield c.submit(inc, 2, workers=b.address)
+    assert result == 3
