@@ -5,8 +5,10 @@ from collections import Iterable
 from contextlib import contextmanager
 from datetime import timedelta
 import inspect
+import functools
 import logging
 import multiprocessing
+import operator
 import os
 import re
 import shutil
@@ -133,9 +135,18 @@ def get_ipv6(host='2001:4860:4860::8888', port=80):
 
 
 def get_ip_interface(ifname):
+    """
+    Get the local IPv4 address of a network interface.
+
+    KeyError is raised if the interface doesn't exist.
+    ValueError is raised if the interface does no have an IPv4 address
+    associated with it.
+    """
     import psutil
-    L = psutil.net_if_addrs()[ifname]
-    return [x.address for x in L if x.family == socket.AF_INET][0]
+    for info in psutil.net_if_addrs()[ifname]:
+        if info.family == socket.AF_INET:
+            return info.address
+    raise ValueError("interface %r doesn't have an IPv4 address" % (ifname,))
 
 
 @contextmanager
@@ -817,14 +828,20 @@ def format_bytes(n):
 if PY2:
     def nbytes(frame):
         """ Number of bytes of a frame or memoryview """
-        if type(frame) in (bytes, buffer):
+        if isinstance(frame, (bytes, buffer)):
             return len(frame)
+        elif isinstance(frame, memoryview):
+            if frame.shape is None:
+                return frame.itemsize
+            else:
+                return functools.reduce(operator.mul, frame.shape,
+                                                      frame.itemsize)
         else:
             return frame.nbytes
 else:
     def nbytes(frame):
         """ Number of bytes of a frame or memoryview """
-        if type(frame) is bytes:
+        if isinstance(frame, bytes):
             return len(frame)
         else:
             return frame.nbytes
